<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he_IL">
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="41"/>
        <source>License</source>
        <translation>רישיון</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <location filename="../about.cpp" line="52"/>
        <source>Changelog</source>
        <translation>יומן שינויים</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="43"/>
        <source>Cancel</source>
        <translation>ביטול</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="64"/>
        <source>&amp;Close</source>
        <translation>&amp;סגירה</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="47"/>
        <source>GUI for applying assorted useful tweaks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>launches brightness-systray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>opens with display tab open.  Only valid with Xfce desktop running</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Opens theme tab directly.  Valid on Xfce &amp; Fluxbox desktops</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Opens Other tab directly.  Valid on all desktops</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>brightness_small</name>
    <message>
        <location filename="../brightness_small.ui" line="14"/>
        <source>MainWindow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="39"/>
        <source>Save</source>
        <translation>שמירה</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="59"/>
        <source>Software (xrandr) Brightness</source>
        <translation>בהירות תוכנה (xrandr)</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="66"/>
        <location filename="../brightness_small.ui" line="87"/>
        <source>TextLabel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="80"/>
        <source>Hardware Backlight</source>
        <translation>אור אחורי חומרתי</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="94"/>
        <source>&gt;&gt;</source>
        <translation>&gt;&gt;</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="33"/>
        <source>MX-Tweak</source>
        <translation>התאמות-MX</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="58"/>
        <source>Display</source>
        <translation>תצוגה</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="63"/>
        <source>&amp;Quit</source>
        <translation>&amp;יציאה</translation>
    </message>
</context>
<context>
    <name>defaultlook</name>
    <message>
        <location filename="../defaultlook.ui" line="20"/>
        <location filename="../defaultlook.cpp" line="57"/>
        <location filename="../defaultlook.cpp" line="86"/>
        <location filename="../defaultlook.cpp" line="651"/>
        <location filename="../defaultlook.cpp" line="670"/>
        <location filename="../defaultlook.cpp" line="679"/>
        <location filename="../defaultlook.cpp" line="726"/>
        <location filename="../defaultlook.cpp" line="734"/>
        <location filename="../defaultlook.cpp" line="761"/>
        <location filename="../defaultlook.cpp" line="764"/>
        <source>MX Tweak</source>
        <translation>התאמות MX</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="41"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;התאמת הלוח אישית&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="51"/>
        <location filename="../defaultlook.ui" line="272"/>
        <source>Panel</source>
        <translation>לוח</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="71"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configure window behavior and shortcuts&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;הגדרת התנהגות וקיצורי הדרך של החלון&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="85"/>
        <source>Window Manager</source>
        <translation>מנהל חלונות</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="105"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the look of your desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;התאמת מראה שולחן העבודה&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="119"/>
        <source>Appearance</source>
        <translation>מראה</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="133"/>
        <source>Xfce Settings</source>
        <translation>הגדרות Xfce</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="212"/>
        <source>About</source>
        <translation>על אודות</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="223"/>
        <source>Help</source>
        <translation>עזרה</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="240"/>
        <source>Quit application</source>
        <translation>יציאה מהיישום</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="243"/>
        <source>Close</source>
        <translation>סגירה</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="250"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="283"/>
        <source>Display panel horizontally</source>
        <extracomment>panel will be shown in a horizontal configuration</extracomment>
        <translation>הצגת לוח אופקית</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="293"/>
        <source>Volume</source>
        <extracomment>volume plugin scale factor</extracomment>
        <translation>כרך</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="300"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Docklike&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>affects the docklike plugin</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;דמוי מעגן&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="307"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Affects all panels&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;משפיע על כל הלוחות&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="327"/>
        <location filename="../defaultlook.ui" line="1725"/>
        <source>Bottom</source>
        <translation>תחתית</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="332"/>
        <location filename="../defaultlook.ui" line="1735"/>
        <source>Top</source>
        <translation>עליון</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="340"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Tasklist&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;רשימת משימות&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="347"/>
        <source>Display panel vertically</source>
        <extracomment>panel will be shown in a vertical configuration</extracomment>
        <translation>הצגת לוח אנכית</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="362"/>
        <location filename="../defaultlook.ui" line="1753"/>
        <source>Affects 1st panel</source>
        <extracomment>acts on the first poanel found in Xfce panel xml fle</extracomment>
        <translation>משפיע על הלוח הראשון</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="369"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Panel Plugin Scales&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="389"/>
        <source>Backup current panel configuration</source>
        <extracomment>backup existing panel configuration</extracomment>
        <translation>גיבוי הגדרות הלוח הנוכחי</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="399"/>
        <location filename="../defaultlook.ui" line="459"/>
        <source>Options</source>
        <translation>אפשרויות</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="419"/>
        <source>Power Manager</source>
        <extracomment>power manager plugin scale factor</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="426"/>
        <source>Restore backup panel configuration</source>
        <extracomment>restore a panel backup</extracomment>
        <translation>שחזור הגדרות הלוח הנוכחי</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="449"/>
        <source>Set Scales</source>
        <extracomment>set a scale factor</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="479"/>
        <location filename="../defaultlook.ui" line="1730"/>
        <source>Left</source>
        <translation>שמאל</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="484"/>
        <location filename="../defaultlook.ui" line="1740"/>
        <source>Right</source>
        <translation>ימין</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="492"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Buttons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>affects the window button plugin</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;כפתורי חלון&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="513"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Docklike is the modern dock plugin for the panel.  Window Buttons is the classic tasklist without dock features.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="536"/>
        <location filename="../defaultlook.ui" line="630"/>
        <location filename="../defaultlook.ui" line="889"/>
        <location filename="../defaultlook.ui" line="1057"/>
        <location filename="../defaultlook.ui" line="1064"/>
        <location filename="../defaultlook.ui" line="1071"/>
        <location filename="../defaultlook.ui" line="1138"/>
        <location filename="../defaultlook.ui" line="1283"/>
        <location filename="../defaultlook.ui" line="1766"/>
        <location filename="../defaultlook.ui" line="1890"/>
        <source>Apply</source>
        <translation>החלה</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="556"/>
        <source>Restore default panel</source>
        <extracomment>affects any panel that is curently configured</extracomment>
        <translation>שחזור לוח ברירת המחדל</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="566"/>
        <source>Set Tasklist plugin to:</source>
        <extracomment>change the tasklist plugin</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="580"/>
        <source>Theme</source>
        <translation>ערכת נושא</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="596"/>
        <source>Theme Options</source>
        <translation>אפשרויות ערכת נושא</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="606"/>
        <source>Remove User Theme Set</source>
        <translation>הסרת ערכת עיצוב של משתמש</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="617"/>
        <source>Preview</source>
        <translation>תצוגה מקדימה</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="656"/>
        <source>Undo</source>
        <translation>ביטול פעולה</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="666"/>
        <source>Save Current Settings as a Theme Set</source>
        <extracomment>save theme settings as a group</extracomment>
        <translation>שמירת ההגדרות הנוכחיות כערכת עיצוב</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="687"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Cursors&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>cursor theme</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="694"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Manager&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>theme a window manager border will get</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;מנהל חלונות&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="704"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Application&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>theme an application will get</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;יישום&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="711"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>icon theme</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;סמלים&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="728"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Themes&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;ערכות עיצוב&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="738"/>
        <location filename="../defaultlook.ui" line="756"/>
        <source>Compositor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="749"/>
        <source>Transparency and shadow options</source>
        <translation>אפשרויות שקיפות והצללה</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="763"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>עריכת compton.conf ישירות בעורך טקסט</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="766"/>
        <source>Edit compton.conf</source>
        <translation>עריכת compton.conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="777"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="780"/>
        <source>Xfwm Settings</source>
        <translation>הגדרות Xfwm</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="791"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="794"/>
        <source>VBlank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="801"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>הפעלת כלי ההגדרות compton-conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="804"/>
        <source>Compton settings</source>
        <translation>הגדרות Compton</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="828"/>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="833"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="838"/>
        <source>Compton </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="847"/>
        <source>auto</source>
        <translation>אוטומטי</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="852"/>
        <source>glx</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="857"/>
        <source>xpresent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="862"/>
        <location filename="../defaultlook.ui" line="1396"/>
        <source>off</source>
        <extracomment>setting to 0 turns off screensaver screen blank</extracomment>
        <translation>כבוי</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="912"/>
        <source>Display</source>
        <translation>תצוגה</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="923"/>
        <source>Hardware Backlight</source>
        <extracomment>set the hardware backlight on monitors that have them</extracomment>
        <translation>אור אחורי חומרתי</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="930"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Display Tweaks&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;שפצורי תצוגה&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="957"/>
        <source>Choose Display for xrandr tweaks</source>
        <extracomment>choose the display that the xrandr tweaks will be acted upon</extracomment>
        <translation>בחירת תצוגה לשפצורי xrandr</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="967"/>
        <source>Resolution</source>
        <translation>רזולוציה</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="974"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving is per display&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;שמירה היא לפי מסך&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="977"/>
        <source>Save</source>
        <translation>שמירה</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="984"/>
        <source>Software (xrandr) Brightness</source>
        <extracomment>adjust brightness (not backlight) via software</extracomment>
        <translation>בהירות תוכנה (xrandr)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="991"/>
        <location filename="../defaultlook.ui" line="1088"/>
        <source>TextLabel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="998"/>
        <source>GTK scaling</source>
        <extracomment>gtk scale factor</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1018"/>
        <source>xrandr Scaling</source>
        <extracomment>xrandr scale factor</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1114"/>
        <source>Config Options</source>
        <translation>אפשרויות תצורה</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1125"/>
        <source>Disable shortening of long filenames on the desktop</source>
        <translation>השבתת קיצור שמות קבצים ארוכים בשולחן העבודה</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1149"/>
        <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation>                   לתשומת לבך: כדי להכניס למצב שינה, ההחלפה צריכה להיות &gt;= זיכרון</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1169"/>
        <source>Enable single-click on desktop</source>
        <translation>להפעיל לחיצה בודדת בשולחן העבודה</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1176"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>הפעלת תרדמת בתפריט היציאה</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1183"/>
        <location filename="../defaultlook.ui" line="1317"/>
        <source>Reset Thunar custom right-click actions to system defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1190"/>
        <location filename="../defaultlook.ui" line="1368"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>הפעלת לחיצה בודדת במנהל הקבצים Thunar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1197"/>
        <location filename="../defaultlook.ui" line="1629"/>
        <source>Thunar windows always open in split view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1204"/>
        <location filename="../defaultlook.ui" line="1561"/>
        <source>Thunar split view opens horizontal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1211"/>
        <source>Show percentages in notifcations when available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1218"/>
        <source>Enable Desktop Zoom </source>
        <translation>הפעלת תקריב שולחן עבודה</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1225"/>
        <location filename="../defaultlook.ui" line="1815"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>הצגת חלונות מכל סביבות העבודה בלוח</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1232"/>
        <source>Show GTK File Dialog action buttons at bottom of dialogs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1239"/>
        <source>( also turns off Client Side Decorations for Xfce applications)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1252"/>
        <source>Fluxbox</source>
        <translation>Fluxbox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1389"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Dock Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;הגדרות מעגן&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1690"/>
        <source>Idle time (minutes)</source>
        <extracomment>set the time of inactivity  before screensaver screen blank occurs</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1264"/>
        <location filename="../defaultlook.ui" line="1604"/>
        <source>On</source>
        <translation>מופעל</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1269"/>
        <location filename="../defaultlook.ui" line="1609"/>
        <source>Off</source>
        <translation>כבוי</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1568"/>
        <source>Manage Tint2 Panel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1579"/>
        <source>Height</source>
        <translation>גובה</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1382"/>
        <location filename="../defaultlook.ui" line="1406"/>
        <source>Autohide</source>
        <translation>הסתרה אוטומטית</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1586"/>
        <location filename="../defaultlook.ui" line="1622"/>
        <location filename="../defaultlook.ui" line="1714"/>
        <source>Placement</source>
        <translation>מיקום</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1290"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Thunar&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1480"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Desktop Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;הסמלים בשולחן העבודה&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1337"/>
        <source>Toggle icon captions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1614"/>
        <source>On Hover</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1375"/>
        <source>Toggle desktop icons</source>
        <translation>הצגת/הסתרת הסמלים בשולחן העבודה</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1636"/>
        <location filename="../defaultlook.ui" line="1829"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Reset Defaults&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;שחזור לברירת המחדל&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1297"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Toolbar Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1361"/>
        <source>Width</source>
        <translation>רוחב</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1593"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Screensaver&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>screensaver screen blank settings</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1666"/>
        <source>Show Toolbar</source>
        <translation>הצגת סרגל כלים</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1554"/>
        <source>Reset DefaultDock</source>
        <translation>איפוס DefaultDock</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1344"/>
        <source>Reset Fluxbox Menu</source>
        <translation>איפוס תפריט Fluxbox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1683"/>
        <source>Reset ALL mx-fluxbox settings</source>
        <translation>איפוס כל הגדרות mx-fluxbox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1643"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Add new default menu items, if any, to existing fluxbox menu.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1646"/>
        <source>Upgrade existing menu entries</source>
        <translation>שדרוג רשומות קיימות בתפריט</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1703"/>
        <source>Plasma</source>
        <translation>Plasma</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1782"/>
        <source>Workspace</source>
        <translation>סביבת עבודה</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1822"/>
        <source>Enable single-click</source>
        <translation>הפעלת לחיצה בודדת</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1836"/>
        <source>Reset KDE/Plasma defaults</source>
        <translation>שחזור לברירת המחדל של KDE/‏Plasma</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1846"/>
        <source>Other</source>
        <translation>שונות</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1870"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1877"/>
        <source>Password for administrative tasks:</source>
        <translation>סיסמה למשימות ניהוליות:</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1908"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1915"/>
        <source>Root</source>
        <translation>שורש (root)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1922"/>
        <source>Enable kernel sandbox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1929"/>
        <source>&amp;User</source>
        <translation>&amp;משתמש</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1936"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;requires reboot&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1939"/>
        <source>Enable Bluetooth Adapters on boot</source>
        <translation>הפעלת מתאמי Bluetooth עם ההפעלה</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1946"/>
        <source>Apt installs additional &quot;recommends&quot; packages as dependencies</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1953"/>
        <source>Generate fluxbox All Apps menu after package installation, removal, and updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1960"/>
        <source>Use Client Side Decorations (CSD) on GTK3 applications that support them (requires session restart)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1967"/>
        <source>Use intel driver instead of default &quot;modesetting&quot; driver (requires restart)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1974"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1981"/>
        <source>Use tearfree amdgpu option</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1988"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1995"/>
        <source>Use tearfree radeon driver option</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2002"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="58"/>
        <source>--display switch only valid for Xfce</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="650"/>
        <source>About MX Tweak</source>
        <translation>על אודות התאמות MX</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="652"/>
        <source>Version: </source>
        <translation>גירסה:</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="653"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="655"/>
        <source>Copyright (c) MX Linux</source>
        <translation>זכויות היוצרים (c) שמורות ל־MX Linux</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="656"/>
        <source>%1 License</source>
        <translation>רישיון של %1</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="670"/>
        <source>%1 Help</source>
        <translation>עזרה עבור %1</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="680"/>
        <source>Finished! Firefox may require a restart for changes to take effect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="727"/>
        <source>Plese remove special characters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="727"/>
        <source>from file name</source>
        <translation>משם קובץ</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="734"/>
        <source>File name already exists.  Choose another name</source>
        <translation>שם הקובץ כבר קיים. נא לבחור שם אחר</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="762"/>
        <source>File is not a valid tar.xz archive file</source>
        <translation>הקובץ אינו ארכיון tar.xz תקני</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="765"/>
        <source>Archive does not contain a panel config</source>
        <translation>הארכיון לא מכיל הגדרות לוח</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="940"/>
        <source>Panel settings</source>
        <translation>הגדרות לוח</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="941"/>
        <source>Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1723"/>
        <source>settings</source>
        <translation>הגדרות</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="2063"/>
        <source>Choose a theme set</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="../remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation>הסרת ערכת עיצוב של משתמש</translation>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="../theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="../window_buttons.ui" line="14"/>
        <location filename="../window_buttons.cpp" line="24"/>
        <source>Window Buttons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Appearance&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;מראה&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="35"/>
        <source>Show button labels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="42"/>
        <source>Show flat buttons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="49"/>
        <source>Show handle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="56"/>
        <source>Sorting Order:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="64"/>
        <source>Timestamp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="69"/>
        <source>Group title and timestamp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="74"/>
        <source>Window Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="79"/>
        <source>Group title and window title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="84"/>
        <source>None, allow drag-and-drop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="92"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Behavior&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;התנהגות&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="99"/>
        <source>Window grouping:</source>
        <translation>קיבוץ חלונות:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="107"/>
        <source>Never</source>
        <translation>אף פעם</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="112"/>
        <source>Always</source>
        <translation>תמיד</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="120"/>
        <source>Middle click action:</source>
        <translation>פעולת לחיצה אמצעית:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="128"/>
        <source>Nothing</source>
        <translation>כלום</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="133"/>
        <source>Close window</source>
        <translation>לסגור חלון</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="138"/>
        <source>Minimize window</source>
        <translation>למזער חלון</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="146"/>
        <source>Restore minimized windows to current workspace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="153"/>
        <source>Draw window frame when hovering over a button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="160"/>
        <source>Switch windows using the mouse wheel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="167"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;סינון&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="174"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="181"/>
        <source>Show only minimized windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="188"/>
        <source>Show windows from all monitors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="238"/>
        <source>Close</source>
        <translation>סגירה</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>תיבת דו־שיח</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="42"/>
        <source>Popup Windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="49"/>
        <source>Windows during move</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Opacity Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;הגדרות אטימות&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="79"/>
        <source>Window decorations</source>
        <translation>עיטורי חלונות</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="86"/>
        <source>Show shadows under dock windows</source>
        <translation>להציג צלליות מתחת לחלונות המעגן</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="93"/>
        <source>Show shadows under popup windows</source>
        <translation>להציג צלליות מתחת לחלונות הקופצים</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="100"/>
        <source>Windows during resize</source>
        <translation>חלונות במהלך שינוי גודל</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="123"/>
        <source>Show shadows under regular windows</source>
        <translation>להציג צלליות מתחת לחלונות רגילים</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="130"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Feature Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;הגדרות יכולות&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="137"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="144"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="183"/>
        <source>Inactive windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="190"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="212"/>
        <source>Close</source>
        <translation>סגירה</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.cpp" line="23"/>
        <source>Xfwm Compositor Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
